==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/DecyzjaSwiadczenieKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class DecyzjaSwiadczenieKey extends GenericDPSObject {
    /**
     * DECYZJA_SWIADCZENIE.DECYZJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long decyzjaId;

    /**
     * DECYZJA_SWIADCZENIE.SWIADCZENIE_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long swiadczenieId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DECYZJA_SWIADCZENIE.DECYZJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getDecyzjaId() {
        return decyzjaId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:42
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * DECYZJA_SWIADCZENIE.DECYZJA_ID
     *
     * @param decyzjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDecyzjaId(Long decyzjaId) {
        this.decyzjaId = decyzjaId;
    }

    /**
     * @return DECYZJA_SWIADCZENIE.SWIADCZENIE_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getSwiadczenieId() {
        return swiadczenieId;
    }

    /**
     * DECYZJA_SWIADCZENIE.SWIADCZENIE_ID
     *
     * @param swiadczenieId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSwiadczenieId(Long swiadczenieId) {
        this.swiadczenieId = swiadczenieId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DecyzjaSwiadczenieKey other = (DecyzjaSwiadczenieKey) that;
        return (this.getDecyzjaId() == null ? other.getDecyzjaId() == null : this.getDecyzjaId().equals(other.getDecyzjaId()))
            && (this.getSwiadczenieId() == null ? other.getSwiadczenieId() == null : this.getSwiadczenieId().equals(other.getSwiadczenieId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getDecyzjaId() == null) ? 0 : getDecyzjaId().hashCode());
        result = prime * result + ((getSwiadczenieId() == null) ? 0 : getSwiadczenieId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", decyzjaId=").append(decyzjaId);
        sb.append(", swiadczenieId=").append(swiadczenieId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/DecyzjaSwiadczenieKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class DecyzjaSwiadczenieKey extends GenericDPSObject {
    /**
     * DECYZJA_SWIADCZENIE.DECYZJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long decyzjaId;

    /**
     * DECYZJA_SWIADCZENIE.SWIADCZENIE_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long swiadczenieId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DECYZJA_SWIADCZENIE.DECYZJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getDecyzjaId() {
        return decyzjaId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:47
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * DECYZJA_SWIADCZENIE.DECYZJA_ID
     *
     * @param decyzjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDecyzjaId(Long decyzjaId) {
        this.decyzjaId = decyzjaId;
    }

    /**
     * @return DECYZJA_SWIADCZENIE.SWIADCZENIE_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getSwiadczenieId() {
        return swiadczenieId;
    }

    /**
     * DECYZJA_SWIADCZENIE.SWIADCZENIE_ID
     *
     * @param swiadczenieId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSwiadczenieId(Long swiadczenieId) {
        this.swiadczenieId = swiadczenieId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DecyzjaSwiadczenieKey other = (DecyzjaSwiadczenieKey) that;
        return (this.getDecyzjaId() == null ? other.getDecyzjaId() == null : this.getDecyzjaId().equals(other.getDecyzjaId()))
            && (this.getSwiadczenieId() == null ? other.getSwiadczenieId() == null : this.getSwiadczenieId().equals(other.getSwiadczenieId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getDecyzjaId() == null) ? 0 : getDecyzjaId().hashCode());
        result = prime * result + ((getSwiadczenieId() == null) ? 0 : getSwiadczenieId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", decyzjaId=").append(decyzjaId);
        sb.append(", swiadczenieId=").append(swiadczenieId);
        sb.append("]");
        return sb.toString();
    }
}
